==> apache-camel-3.18.4-src.zip: apache-camel-3.18.4/components/camel-box/camel-box-component/src/test/java/org/apache/camel/component/box/BoxEventLogsManagerIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.box;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.box.api.BoxEventLogsManager;
import org.apache.camel.component.box.internal.BoxApiCollection;
import org.apache.camel.component.box.internal.BoxEventLogsManagerApiMethod;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.condition.EnabledIf;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.junit.jupiter.api.Assertions.assertNotNull;

/**
 * Test class for {@link BoxEventLogsManager} APIs.
 */
@EnabledIf(value = "org.apache.camel.component.box.AbstractBoxITSupport#hasCredentials",
           disabledReason = "Box credentials were not provided")
public class BoxEventLogsManagerIT extends AbstractBoxITSupport {

    private static final Logger LOG = LoggerFactory.getLogger(BoxEventLogsManagerIT.class);
    private static final String PATH_PREFIX = BoxApiCollection.getCollection()
            .getApiName(BoxEventLogsManagerApiMethod.class).getName();
    private static final long ONE_MINUTE_OF_MILLISECONDS = 1000 * 60;

    @Disabled // Requires enterprise admin account to test
    @Test
    public void testGetEnterpriseEvents() {
        Date before = new Date();
        Date after = new Date();
        after.setTime(before.getTime() - ONE_MINUTE_OF_MILLISECONDS);

        final Map<String, Object> headers = new HashMap<>();
        // parameter type is String
        headers.put("CamelBox.position", null);
        // parameter type is java.util.Date
        headers.put("CamelBox.after", after);
        // parameter type is java.util.Date
        headers.put("CamelBox.before", before);
        // parameter type is com.box.sdk.BoxEvent.Type[]
        headers.put("CamelBox.types", null);

        @SuppressWarnings("rawtypes")
        final java.util.List result = requestBodyAndHeaders("direct://GETENTERPRISEEVENTS", null, headers);

        assertNotNull(result, "getEnterpriseEvents result");
        LOG.debug("getEnterpriseEvents: " + result);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                // test route for getEnterpriseEvents
                from("direct://GETENTERPRISEEVENTS").to("box://" + PATH_PREFIX + "/getEnterpriseEvents");

            }
        };
    }
}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/components/camel-box/camel-box-component/src/test/java/org/apache/camel/component/box/BoxEventLogsManagerIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.box;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.box.api.BoxEventLogsManager;
import org.apache.camel.component.box.internal.BoxApiCollection;
import org.apache.camel.component.box.internal.BoxEventLogsManagerApiMethod;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.condition.EnabledIf;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.junit.jupiter.api.Assertions.assertNotNull;

/**
 * Test class for {@link BoxEventLogsManager} APIs.
 */
@EnabledIf(value = "org.apache.camel.component.box.AbstractBoxITSupport#hasCredentials",
           disabledReason = "Box credentials were not provided")
public class BoxEventLogsManagerIT extends AbstractBoxITSupport {

    private static final Logger LOG = LoggerFactory.getLogger(BoxEventLogsManagerIT.class);
    private static final String PATH_PREFIX = BoxApiCollection.getCollection()
            .getApiName(BoxEventLogsManagerApiMethod.class).getName();
    private static final long ONE_MINUTE_OF_MILLISECONDS = 1000 * 60;

    @Disabled // Requires enterprise admin account to test
    @Test
    public void testGetEnterpriseEvents() {
        Date before = new Date();
        Date after = new Date();
        after.setTime(before.getTime() - ONE_MINUTE_OF_MILLISECONDS);

        final Map<String, Object> headers = new HashMap<>();
        // parameter type is String
        headers.put("CamelBox.position", null);
        // parameter type is java.util.Date
        headers.put("CamelBox.after", after);
        // parameter type is java.util.Date
        headers.put("CamelBox.before", before);
        // parameter type is com.box.sdk.BoxEvent.Type[]
        headers.put("CamelBox.types", null);

        @SuppressWarnings("rawtypes")
        final java.util.List result = requestBodyAndHeaders("direct://GETENTERPRISEEVENTS", null, headers);

        assertNotNull(result, "getEnterpriseEvents result");
        LOG.debug("getEnterpriseEvents: {}", result);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                // test route for getEnterpriseEvents
                from("direct://GETENTERPRISEEVENTS").to("box://" + PATH_PREFIX + "/getEnterpriseEvents");

            }
        };
    }
}
